@@ -9,6 +9,7 @@ import rasterio
 from cogeo_mosaic.backends import BaseBackend, MosaicBackend
 from cogeo_mosaic.models import Info as mosaicInfo
 from cogeo_mosaic.mosaic import MosaicJSON
+from fastapi import Depends, HTTPException, Path, Query
 from geojson_pydantic.features import Feature
 from geojson_pydantic.geometries import Polygon
 from morecantile import tms
@@ -17,6 +18,8 @@ from rio_tiler.constants import MAX_THREADS
 from rio_tiler.io import BaseReader, MultiBandReader, MultiBaseReader, Reader
 from rio_tiler.models import Bounds
 from rio_tiler.mosaic.methods.base import MosaicMethodBase
+from starlette.requests import Request
+from starlette.responses import HTMLResponse, Response
 
 from titiler.core.dependencies import DefaultDependency, RescalingParams
 from titiler.core.factory import BaseTilerFactory, img_endpoint_params, templates
@@ -26,11 +29,6 @@ from titiler.core.resources.responses import GeoJSONResponse, JSONResponse, XMLR
 from titiler.mosaic.models.responses import Point
 from titiler.mosaic.resources.enums import PixelSelectionMethod
 
-from fastapi import Depends, Path, Query
-
-from starlette.requests import Request
-from starlette.responses import HTMLResponse, Response
-
 # BaseBackend does not support other TMS than WebMercator
 mosaic_tms = TileMatrixSets({"WebMercatorQuad": tms.get("WebMercatorQuad")})
 
@@ -103,13 +101,6 @@ class MosaicTilerFactory(BaseTilerFactory):
     def read(self):
         """Register / (Get) Read endpoint."""
 
-        @self.router.get(
-            "",
-            response_model=MosaicJSON,
-            response_model_exclude_none=True,
-            responses={200: {"description": "Return MosaicJSON definition"}},
-            deprecated=True,
-        )
         @self.router.get(
             "/",
             response_model=MosaicJSON,
@@ -278,6 +269,11 @@ class MosaicTilerFactory(BaseTilerFactory):
             """Create map tile from a COG."""
             threads = int(os.getenv("MOSAIC_CONCURRENCY", MAX_THREADS))
 
+            strict_zoom = str(os.getenv("MOSAIC_STRICT_ZOOM", False)).lower() in [
+                "true",
+                "yes",
+            ]
+
             with rasterio.Env(**env):
                 with self.reader(
                     src_path,
@@ -285,6 +281,13 @@ class MosaicTilerFactory(BaseTilerFactory):
                     reader_options={**reader_params},
                     **backend_params,
                 ) as src_dst:
+
+                    if strict_zoom and (z < src_dst.minzoom or z > src_dst.maxzoom):
+                        raise HTTPException(
+                            400,
+                            f"Invalid ZOOM level {z}. Should be between {src_dst.minzoom} and {src_dst.maxzoom}",
+                        )
+
                     image, assets = src_dst.tile(
                         x,
                         y,
@@ -306,12 +309,14 @@ class MosaicTilerFactory(BaseTilerFactory):
             if color_formula:
                 image.apply_color_formula(color_formula)
 
+            if colormap:
+                image = image.apply_colormap(colormap)
+
             if not format:
                 format = ImageType.jpeg if image.mask.all() else ImageType.png
 
             content = image.render(
                 img_format=format.driver,
-                colormap=colormap,
                 **format.profile,
                 **render_params,
             )
